/*
  Java gfx-test framework

   Copyright (C) 2012  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.testsuites;

import java.awt.Graphics2D;
import java.awt.image.BufferedImage;



import org.gfxtest.framework.BitmapCropRegions;
import org.gfxtest.framework.CommonBitmapOperations;
import org.gfxtest.framework.PrintTest;
import org.gfxtest.framework.TestImage;
import org.gfxtest.framework.TestResult;
import org.gfxtest.framework.annotations.BitBltOperation;
import org.gfxtest.framework.annotations.BitBltOperations;
import org.gfxtest.framework.annotations.GraphicsPrimitive;
import org.gfxtest.framework.annotations.GraphicsPrimitives;
import org.gfxtest.framework.annotations.RenderStyle;
import org.gfxtest.framework.annotations.RenderStyles;
import org.gfxtest.framework.annotations.TestType;
import org.gfxtest.framework.annotations.TestTypes;
import org.gfxtest.framework.annotations.Transformation;
import org.gfxtest.framework.annotations.Transformations;
import org.gfxtest.framework.annotations.Zoom;



/**
 * This test check the rendering of buffered images (so called bit block
 * transfers or Bit Blt) created by various constructors. Such images are
 * rendered cropped - only partial image is used for the BitBlt operation.
 * 
 * @author Pavel Tisnovsky
 */
@TestType(TestTypes.PRINT_TEST)
@GraphicsPrimitive(GraphicsPrimitives.COMMON_BITMAP)
@RenderStyle(RenderStyles.NORMAL)
@BitBltOperation(BitBltOperations.CROP)
@Transformation(Transformations.NONE)
@Zoom(1)
public class PrintTestBitBltCropImage extends PrintTest
{
    
    /**
     * Test basic BitBlt operation for checker buffered image with type
     * TYPE_BYTE_BINARY. No crop is performed to that image.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryNoCrop(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type
     * TYPE_BYTE_BINARY. Image is cropped so only north-west quarter of it is rendered.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryCropNW(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY,
                        BitmapCropRegions.CROP_REGION_NW);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type
     * TYPE_BYTE_BINARY. Image is cropped so only north-east quarter of it is rendered.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryCropNE(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY,
                        BitmapCropRegions.CROP_REGION_NE);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type
     * TYPE_BYTE_BINARY. Image is cropped so only south-west quarter of it is rendered.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryCropSW(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY,
                        BitmapCropRegions.CROP_REGION_SW);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type
     * TYPE_BYTE_BINARY. Image is cropped so only south-east quarter of it is rendered.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryCropSE(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY,
                        BitmapCropRegions.CROP_REGION_SE);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB.
     * No crop is performed to that image.
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBNoCrop(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type
     * TYPE_INT_RGB. Image is cropped so only north-west quarter of it is rendered.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBCropNW(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_RGB,
                        BitmapCropRegions.CROP_REGION_NW);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type
     * TYPE_INT_RGB. Image is cropped so only north-east quarter of it is rendered.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBCropNE(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_RGB,
                        BitmapCropRegions.CROP_REGION_NE);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type
     * TYPE_INT_RGB. Image is cropped so only south-west quarter of it is rendered.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBCropSW(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_RGB,
                        BitmapCropRegions.CROP_REGION_SW);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type
     * TYPE_INT_RGB. Image is cropped so only south-east quarter of it is rendered.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBCropSE(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_RGB,
                        BitmapCropRegions.CROP_REGION_SE);
    }

    /**
     * Entry point to the test suite.
     * 
     * @param args
     *            not used in this case
     */
    public static void main(String[] args)
    {
        new PrintTestBitBltCropImage().runTestSuite(args);
    }
}
